@@ -41,27 +41,13 @@
  *****************************************************************************/
 
 /* Program version and copyright message */
-#define VERSION_MESSAGE     "vlc 0.2.82 Ourumov " \
+#define VERSION_MESSAGE     "vlc 0.2.91 Ourumov " \
                           /* "(" PROGRAM_BUILD ") (" PROGRAM_OPTIONS ")\n" */ \
                             "Copyright 1996-2001 VideoLAN\n"
-#define COPYRIGHT_MESSAGE   "VideoLAN Client - version 0.2.82" \
-                            " Ourumov - (C)1996-2001 VideoLAN\n"
+#define COPYRIGHT_MESSAGE   "VideoLAN Client - version 0.2.91" \
+                            " Ourumov - (C)1996-2001 VideoLAN"
 
-#define VERSION             "0.2.82"
-
-/*****************************************************************************
- * General compilation options
- *****************************************************************************/
-
-/* Define for DVB support - Note that some extensions or restrictions may be
- * incompatible with native MPEG2 streams */
-//#define DVB_EXTENSIONS
-//#define DVB_RESTRICTIONS
-
-/* Define to disable some obscure heuristics behind the video_parser and the
- * video_decoder that improve performance but are not fully MPEG2 compliant
- * and might cause problems with some very weird streams. */
-//#define MPEG2_COMPLIANT
+#define VERSION             "0.2.91"
 
 /*****************************************************************************
  * Debugging options - define or undefine symbols
@@ -93,8 +79,7 @@
 #define CLOCK_FREQ 1000000
 
 
-/* Automagically spawn input, audio and video threads ? */
-/* XXX?? used ? */
+/* Automagically spawn audio and video decoder threads */
 #define AUTO_SPAWN
 
 /* When creating or destroying threads in blocking mode, delay to poll thread
@@ -185,7 +170,7 @@
 
 /* Default remote server */
 #define INPUT_SERVER_VAR                "vlc_server"
-#define INPUT_SERVER_DEFAULT            "138.195.143.224"
+#define INPUT_SERVER_DEFAULT            "138.195.143.220"
 
 /* Default input port */
 #define INPUT_PORT_VAR                  "vlc_server_port"
@@ -213,7 +198,7 @@
 
 /* Default server and port */
 #define INPUT_CHANNEL_SERVER_VAR           "vlc_channel_server"
-#define INPUT_CHANNEL_SERVER_DEFAULT       "138.195.143.220"
+#define INPUT_CHANNEL_SERVER_DEFAULT       "138.195.143.120"
 #define INPUT_CHANNEL_PORT_VAR             "vlc_channel_port"
 #define INPUT_CHANNEL_PORT_DEFAULT         6010
 
@@ -283,6 +268,9 @@
 #define VOLUME_STEP                     128
 #define VOLUME_MAX                      1024
 
+/* Environment variable for volume */
+#define AOUT_VOLUME_VAR                 "vlc_volume"
+
 /* Environment variable for output rate, and default value */
 #define AOUT_RATE_VAR                   "vlc_audio_rate"
 #define AOUT_RATE_DEFAULT               44100
@@ -353,10 +341,10 @@
 
 /* Video heap size - remember that a decompressed picture is big
  * (~1 Mbyte) before using huge values */
-#define VOUT_MAX_PICTURES               5
+#define VOUT_MAX_PICTURES               8
 
 /* Number of simultaneous subpictures */
-#define VOUT_MAX_SUBPICTURES            5
+#define VOUT_MAX_SUBPICTURES            8
 
 /* Maximum number of active areas in a rendering buffer. Active areas are areas
  * of the picture which need to be cleared before re-using the buffer. If a
@@ -413,7 +401,7 @@
 #define VOUT_MWAIT_TOLERANCE            ((int)(0.020*CLOCK_FREQ))
 
 /* The default video output window title */
-#define VOUT_TITLE                      "VideoLAN Client 0.2.82"
+#define VOUT_TITLE                      "VideoLAN Client 0.2.91"
 
 /* Environment variable for framebuffer device, and default value */
 #define VOUT_FB_DEV_VAR                 "vlc_fb_dev"
@@ -436,7 +424,11 @@
 
 /* Optimization level, from 0 to 2 - 1 is generally a good compromise. Remember
  * that raising this level dramatically lengthens the compilation time. */
-#define VPAR_OPTIM_LEVEL                2
+#ifdef RELEASE
+#   define VPAR_OPTIM_LEVEL             2
+#else
+#   define VPAR_OPTIM_LEVEL             1
+#endif
 
 /* Maximum number of macroblocks in a picture. */
 #define MAX_MB                          2048
