@@ -2,7 +2,7 @@
  * dvd_ifo.c: Functions for ifo parsing
  *****************************************************************************
  * Copyright (C) 1999-2001 VideoLAN
- * $Id: dvd_ifo.c,v 1.37 2001/08/09 20:16:17 jlj Exp $
+ * $Id: dvd_ifo.c,v 1.40 2001/11/07 17:37:16 stef Exp $
  *
  * Authors: Stphane Borel <stef@via.ecp.fr>
  *          German Tischler <tanis@gaspode.franken.de>
@@ -124,7 +124,7 @@ int IfoInit( ifo_t * p_ifo )
     int                 i_start;
 
     /* find the start sector of video information on the dvd */
-    p_ifo->i_start = UDFFindFile( p_ifo->dvdhandle, "/VIDEO_TS/VIDEO_TS.IFO" );
+    p_ifo->i_start = DVDUDFFindFile( p_ifo->dvdhandle, "/VIDEO_TS/VIDEO_TS.IFO" );
     if( !p_ifo->i_start ) return -1;
 
     p_tmp = FillBuffer( p_ifo, p_buf, p_ifo->i_start );
@@ -1047,7 +1047,8 @@ static int ReadTitle( ifo_t * p_ifo, title_t * p_title, int i_block, int i_bytes
     if( p_title->i_chapter_map_start_byte )
     {
         p_ifo->i_pos = dvdcss_seek( p_ifo->dvdhandle,
-               OFF2LB( i_start + p_title->i_chapter_map_start_byte ) );
+               OFF2LB( i_start + p_title->i_chapter_map_start_byte ),
+               DVDCSS_NOFLAGS );
         
         p_title->chapter_map.pi_start_cell =
                     malloc( p_title->i_chapter_nb * sizeof(chapter_map_t) );
@@ -1327,7 +1328,7 @@ static int ReadCellInf( ifo_t * p_ifo, cell_inf_t * p_cell_inf, int i_block )
 
     p_tmp = FillBuffer( p_ifo, p_buf, i_block );
     i_start = p_ifo->i_pos;
-    //fprintf( stderr, "CELL ADD\n" );
+//    fprintf( stderr, "CELL ADD\n" );
 
     p_cell_inf->i_vob_nb = ReadWord( p_ifo, p_buf, &p_tmp );
     DumpBytes( p_ifo, p_buf, &p_tmp, 2 );
@@ -1335,8 +1336,8 @@ static int ReadCellInf( ifo_t * p_ifo, cell_inf_t * p_cell_inf, int i_block )
 
     p_cell_inf->i_cell_nb = (p_cell_inf->i_end_byte/* - 7*/) / sizeof(cell_map_t);
 
-    //fprintf( stderr, "Cell inf: vob %d end %d cell %d\n", p_cell_inf->i_vob_nb, p_cell_inf->i_end_byte,  p_cell_inf->i_cell_nb );
-
+/*    fprintf( stderr, "Cell inf: vob %d end %d cell %d\n", p_cell_inf->i_vob_nb, p_cell_inf->i_end_byte,  p_cell_inf->i_cell_nb );
+*/
     p_cell_inf->p_cell_map =
                 malloc( p_cell_inf->i_cell_nb *sizeof(cell_map_t) );
     if( p_cell_inf->p_cell_map == NULL )
@@ -1352,7 +1353,7 @@ static int ReadCellInf( ifo_t * p_ifo, cell_inf_t * p_cell_inf, int i_block )
         MAP.i_cell_id = ReadByte( p_ifo, p_buf, &p_tmp );
         DumpBytes( p_ifo, p_buf, &p_tmp, 1 );
         MAP.i_start_sector = ReadDouble( p_ifo, p_buf, &p_tmp );
-        //fprintf(stderr, "sector[%d] %d (%d)\n", i,ntohl(*(u32*)(p_tmp)), p_ifo->i_pos);
+/*        fprintf(stderr, "sector[%d] %d (%d)\n", i,ntohl(*(u32*)(p_tmp)), p_ifo->i_pos);*/
         MAP.i_end_sector = ReadDouble( p_ifo, p_buf, &p_tmp );
 #undef MAP
     }
@@ -2098,7 +2099,7 @@ void CommandPrint( ifo_t ifo )
  *****************************************************************************/
 static u8* FillBuffer( ifo_t* p_ifo, u8* p_buf, int i_pos )
 {
-    p_ifo->i_pos = dvdcss_seek( p_ifo->dvdhandle, i_pos );
+    p_ifo->i_pos = dvdcss_seek( p_ifo->dvdhandle, i_pos, DVDCSS_NOFLAGS );
     dvdcss_read( p_ifo->dvdhandle, p_buf, 1, DVDCSS_NOFLAGS );
 
     return p_buf;
@@ -2144,7 +2145,7 @@ static void DumpBytes( ifo_t* p_ifo, u8* p_buf, u8** pp_tmp, int i_nb )
     {
         /* If we went too far, load the next buffer */
         *pp_tmp = FillBuffer( p_ifo, p_buf, p_ifo->i_pos + 1 )
-                   + (int)( (*pp_tmp) - (p_buf - DVD_LB_SIZE) );
+                   + (int)( (*pp_tmp) - (p_buf + DVD_LB_SIZE) );
     }
 
     return;
