@@ -1,10 +1,10 @@
 /*****************************************************************************
- * idct.c : IDCT module
+ * idct.c : C IDCT module
  *****************************************************************************
  * Copyright (C) 1999, 2000 VideoLAN
- * $Id: idct.c,v 1.11 2001/06/03 12:47:21 sam Exp $
+ * $Id: idct.c,v 1.16 2001/09/06 10:19:18 massiot Exp $
  *
- * Authors: Gal Hendryckx <jimmy@via.ecp.fr>
+ * Author: Gal Hendryckx <jimmy@via.ecp.fr>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@
 #include "defs.h"
 
 #include <stdlib.h>
+#include <string.h>
 
 #include "config.h"
 #include "common.h"
@@ -37,13 +38,8 @@
 #include "mtime.h"
 #include "tests.h"
 
-#include "video.h"
-#include "video_output.h"
-
-#include "video_decoder.h"
-
-#include "vdec_block.h"
-#include "vdec_idct.h"
+#include "idct.h"
+#include "block_c.h"
 
 #include "modules.h"
 #include "modules_export.h"
@@ -52,8 +48,6 @@
  * Local and extern prototypes.
  *****************************************************************************/
 static void idct_getfunctions( function_list_t * p_function_list );
-static int  idct_Probe      ( probedata_t *p_data );
-static void vdec_NormScan   ( u8 ppi_scan[2][64] );
 
 /*****************************************************************************
  * Build configuration tree.
@@ -78,30 +72,13 @@ MODULE_DEACTIVATE_STOP
 
 /* Following functions are local */
 
-/*****************************************************************************
- * Functions exported as capabilities. They are declared as static so that
- * we don't pollute the namespace too much.
- *****************************************************************************/
-static void idct_getfunctions( function_list_t * p_function_list )
-{
-    p_function_list->pf_probe = idct_Probe;
-#define F p_function_list->functions.idct
-    F.pf_idct_init = _M( vdec_InitIDCT );
-    F.pf_sparse_idct = _M( vdec_SparseIDCT );
-    F.pf_idct = _M( vdec_IDCT );
-    F.pf_norm_scan = vdec_NormScan;
-    F.pf_decode_init = _M( vdec_InitDecode );
-    F.pf_decode_mb_c = _M( vdec_DecodeMacroblockC );
-    F.pf_decode_mb_bw = _M( vdec_DecodeMacroblockBW );
-#undef F
-}
-
 /*****************************************************************************
  * idct_Probe: returns a preference score
  *****************************************************************************/
 static int idct_Probe( probedata_t *p_data )
 {
-    if( TestMethod( IDCT_METHOD_VAR, "idct" ) )
+    if( TestMethod( IDCT_METHOD_VAR, "idct" )
+         || TestMethod( IDCT_METHOD_VAR, "c" ))
     {
         return( 999 );
     }
@@ -111,17 +88,16 @@ static int idct_Probe( probedata_t *p_data )
 }
 
 /*****************************************************************************
- * vdec_NormScan : Unused in this IDCT
+ * NormScan : Unused in this IDCT
  *****************************************************************************/
-static void vdec_NormScan( u8 ppi_scan[2][64] )
+static void NormScan( u8 ppi_scan[2][64] )
 {
 }
 
 /*****************************************************************************
- * vdec_IDCT : IDCT function for normal matrices
+ * IDCT : IDCT function for normal matrices
  *****************************************************************************/
-void _M( vdec_IDCT )( vdec_thread_t * p_vdec, dctelem_t * p_block,
-                int i_idontcare )
+static __inline__ void IDCT( dctelem_t * p_block )
 {
     s32 tmp0, tmp1, tmp2, tmp3;
     s32 tmp10, tmp11, tmp12, tmp13;
@@ -1299,3 +1275,5 @@ void _M( vdec_IDCT )( vdec_thread_t * p_vdec, dctelem_t * p_block,
     }
 }
 
+#include "idct_sparse.h"
+#include "idct_decl.h"
