@@ -2,7 +2,7 @@
  * modules.c : Built-in and plugin modules management functions
  *****************************************************************************
  * Copyright (C) 2001 VideoLAN
- * $Id: modules.c,v 1.34 2001/06/03 12:47:22 sam Exp $
+ * $Id: modules.c,v 1.41 2001/10/02 16:46:59 massiot Exp $
  *
  * Authors: Samuel Hocevar <sam@zoy.org>
  *          Ethan C. Baldridge <BaldridgeE@cadmus.com>
@@ -45,7 +45,7 @@
 #elif defined(HAVE_IMAGE_H)                                          /* BeOS */
 #   include <image.h>
 #   define HAVE_DYNAMIC_PLUGINS
-#elif defined(WIN32)
+#elif defined(WIN32) && defined( __MINGW32__ )
 #   define HAVE_DYNAMIC_PLUGINS
 #else
 #   undef HAVE_DYNAMIC_PLUGINS
@@ -55,7 +55,7 @@
 #   include "beos_specific.h"
 #endif
 
-#ifdef SYS_DARWIN1_3
+#ifdef SYS_DARWIN
 #   include "darwin_specific.h"
 #endif
 
@@ -73,9 +73,7 @@
 #include "stream_control.h"
 #include "input_ext-intf.h"
 #include "input_ext-dec.h"
-#include "input.h"
-#include "input_netlist.h"
-#include "mpeg_system.h"
+#include "input_ext-plugins.h"
 
 #include "video.h"
 #include "video_output.h"
@@ -120,12 +118,12 @@ static module_symbols_t symbols;
 void module_InitBank( void )
 {
 #ifdef HAVE_DYNAMIC_PLUGINS
-    static char * path[] = { ".", "lib", PLUGIN_PATH, NULL, NULL };
+    static char * path[] = { ".", "plugins", PLUGIN_PATH, NULL, NULL };
 
     char **         ppsz_path = path;
     char *          psz_fullpath;
     char *          psz_file;
-#if defined( SYS_BEOS ) || defined( SYS_DARWIN1_3 )
+#if defined( SYS_BEOS ) || defined( SYS_DARWIN )
     char *          psz_vlcpath = system_GetProgramPath();
     int             i_vlclen = strlen( psz_vlcpath );
     boolean_t       b_notinroot;
@@ -141,6 +139,9 @@ void module_InitBank( void )
      * Store the symbols to be exported
      */
     STORE_SYMBOLS( &symbols );
+#ifdef TRACE
+    STORE_TRACE_SYMBOLS( &symbols );
+#endif
 
     /*
      * Check all the built-in modules
@@ -162,7 +163,7 @@ void module_InitBank( void )
         /* Store strlen(*ppsz_path) for later use. */
         int i_dirlen = strlen( *ppsz_path );
 
-#if defined( SYS_BEOS ) || defined( SYS_DARWIN1_3 )
+#if defined( SYS_BEOS ) || defined( SYS_DARWIN )
         b_notinroot = 0;
         /* Under BeOS, we need to add beos_GetProgramPath() to access
          * files under the current directory */
@@ -217,7 +218,7 @@ void module_InitBank( void )
             closedir( dir );
         }
 
-#if defined( SYS_BEOS ) || defined( SYS_DARWIN1_3 )
+#if defined( SYS_BEOS ) || defined( SYS_DARWIN )
         if( b_notinroot )
         {
             free( psz_fullpath );
@@ -302,7 +303,7 @@ void module_ManageBank( void )
             }
             else
             {
-                intf_WarnMsg( 1, "module: hiding unused plugin module `%s'",
+                intf_WarnMsg( 3, "module: hiding unused plugin module `%s'",
                               p_module->psz_name );
                 HideModule( p_module );
 
@@ -364,6 +365,8 @@ module_t * module_Need( int i_capabilities, void *p_data )
                     }
                 }
             }
+            intf_WarnMsg( 3, "module: %s has score %d",
+                          p_module->psz_name, i_totalscore );
 
             /* If the high score was broken, we have a new champion */
             if( i_totalscore > i_bestscore )
@@ -515,10 +518,27 @@ static int AllocatePluginModule( char * psz_filename )
             || p_module->psz_version == NULL )
     {
         intf_ErrMsg( "module error: can't duplicate strings" );
-        free( p_module->is.plugin.psz_filename );
-        free( p_module->psz_name );
-        free( p_module->psz_longname );
-        free( p_module->psz_version );
+
+        if( p_module->is.plugin.psz_filename != NULL )
+        {
+            free( p_module->is.plugin.psz_filename );
+        }
+
+        if( p_module->psz_name != NULL )
+        {
+            free( p_module->psz_name );
+        }
+
+        if( p_module->psz_longname != NULL )
+        {
+            free( p_module->psz_longname );
+        }
+
+        if( p_module->psz_version != NULL )
+        {
+            free( p_module->psz_version );
+        }
+
         free( p_module );
         module_unload( handle );
         return( -1 );
@@ -540,7 +560,7 @@ static int AllocatePluginModule( char * psz_filename )
     p_module_bank->first = p_module;
 
     /* Immediate message so that a slow module doesn't make the user wait */
-    intf_WarnMsgImm( 2, "module: plugin module `%s', %s",
+    intf_WarnMsgImm( 2, "module: new plugin module `%s', %s",
                      p_module->psz_name, p_module->psz_longname );
 
     return( 0 );
@@ -619,9 +639,22 @@ static int AllocateBuiltinModule( int ( *pf_init ) ( module_t * ),
             || p_module->psz_version == NULL )
     {
         intf_ErrMsg( "module error: can't duplicate strings" );
-        free( p_module->psz_name );
-        free( p_module->psz_longname );
-        free( p_module->psz_version );
+
+        if( p_module->psz_name != NULL )
+        {
+            free( p_module->psz_name );
+        }
+
+        if( p_module->psz_longname != NULL )
+        {
+            free( p_module->psz_longname );
+        }
+
+        if( p_module->psz_version != NULL )
+        {
+            free( p_module->psz_version );
+        }
+
         free( p_module );
         return( -1 );
     }
@@ -643,7 +676,7 @@ static int AllocateBuiltinModule( int ( *pf_init ) ( module_t * ),
     p_module_bank->first = p_module;
 
     /* Immediate message so that a slow module doesn't make the user wait */
-    intf_WarnMsgImm( 2, "module: builtin module `%s', %s",
+    intf_WarnMsgImm( 2, "module: new builtin module `%s', %s",
                      p_module->psz_name, p_module->psz_longname );
 
     return( 0 );
