@@ -84,6 +84,9 @@ int module_downmixsse_DeactivateModule( module_t* );
 int module_dvd_InitModule( module_t* );
 int module_dvd_ActivateModule( module_t* );
 int module_dvd_DeactivateModule( module_t* );
+int module_vcd_InitModule( module_t* );
+int module_vcd_ActivateModule( module_t* );
+int module_vcd_DeactivateModule( module_t* );
 int module_dummy_InitModule( module_t* );
 int module_dummy_ActivateModule( module_t* );
 int module_dummy_DeactivateModule( module_t* );
@@ -93,6 +96,9 @@ int module_null_DeactivateModule( module_t* );
 int module_rc_InitModule( module_t* );
 int module_rc_ActivateModule( module_t* );
 int module_rc_DeactivateModule( module_t* );
+int module_xvideo_InitModule( module_t* );
+int module_xvideo_ActivateModule( module_t* );
+int module_xvideo_DeactivateModule( module_t* );
 
-#define ALLOCATE_ALL_BUILTINS() do { ALLOCATE_BUILTIN(es); ALLOCATE_BUILTIN(ps); ALLOCATE_BUILTIN(ts); ALLOCATE_BUILTIN(yuv); ALLOCATE_BUILTIN(idct); ALLOCATE_BUILTIN(idctclassic); ALLOCATE_BUILTIN(motion); ALLOCATE_BUILTIN(imdct); ALLOCATE_BUILTIN(downmix); ALLOCATE_BUILTIN(yuvmmx); ALLOCATE_BUILTIN(idctmmx); ALLOCATE_BUILTIN(motionmmx); ALLOCATE_BUILTIN(idctmmxext); ALLOCATE_BUILTIN(motionmmxext); ALLOCATE_BUILTIN(imdct3dn); ALLOCATE_BUILTIN(downmix3dn); ALLOCATE_BUILTIN(imdctsse); ALLOCATE_BUILTIN(downmixsse); ALLOCATE_BUILTIN(dvd); ALLOCATE_BUILTIN(dummy); ALLOCATE_BUILTIN(null); ALLOCATE_BUILTIN(rc); } while( 0 );
+#define ALLOCATE_ALL_BUILTINS() do { ALLOCATE_BUILTIN(es); ALLOCATE_BUILTIN(ps); ALLOCATE_BUILTIN(ts); ALLOCATE_BUILTIN(yuv); ALLOCATE_BUILTIN(idct); ALLOCATE_BUILTIN(idctclassic); ALLOCATE_BUILTIN(motion); ALLOCATE_BUILTIN(imdct); ALLOCATE_BUILTIN(downmix); ALLOCATE_BUILTIN(yuvmmx); ALLOCATE_BUILTIN(idctmmx); ALLOCATE_BUILTIN(motionmmx); ALLOCATE_BUILTIN(idctmmxext); ALLOCATE_BUILTIN(motionmmxext); ALLOCATE_BUILTIN(imdct3dn); ALLOCATE_BUILTIN(downmix3dn); ALLOCATE_BUILTIN(imdctsse); ALLOCATE_BUILTIN(downmixsse); ALLOCATE_BUILTIN(dvd); ALLOCATE_BUILTIN(vcd); ALLOCATE_BUILTIN(dummy); ALLOCATE_BUILTIN(null); ALLOCATE_BUILTIN(rc); ALLOCATE_BUILTIN(xvideo); } while( 0 );
 
